==> worksuite-5_1_9.zip: worksuite-new-5.1.9/script/resources/lang/en/placeholders.php <==
<?php

return array(
    'knowledgeBase' => 'Update your profile picture',
    'name' => 'e.g. John Doe',
    'email' => 'e.g. johndoe@example.com',
    'mobile' => 'e.g. 1234567890',
    'password' => 'Must have at least 8 characters',
    'designation' => 'e.g. Team Lead',
    'department' => 'e.g. Human Resource',
    'date' => 'Select Date',
    'address' => 'e.g. 132, My Street, Kingston, New York 12401',
    'skills' => 'e.g. communication, ReactJS',
    'project' => 'Write a project name',
    'price' => 'e.g. 10000',
    'hours' => 'e.g. 10:00 AM',
    'category' => 'Enter a category name',
    'task' => 'Enter a task title',
    'label' => 'Enter a label title',
    'leaveType' => 'E.g. Sick, Casual',
    'colorPicker' => 'Select a color',
    'ticketType' => 'e.g. Support',
    'milestone' => 'Enter milestone title',
    'milestoneSummary' => 'Enter milestone summary',
    'sampleText' => 'e.g. This is sample text',
    'webhook' => 'e.g. samplewebhook123',
    'key' => 'e.g. 0f99088a2f31e70daxxxx',
    'secret' => 'e.g. cbabcd0948aed7dd9xxxx',
    'id' => 'e.g. 1275901',
    'cluster' => 'e.g. ap2',
    'note' => 'Enter note title',
    'consent' => 'Enter consent name',
    'consentDescription' => 'Briefly describe the purpose on consent',
    'title' => 'e.g. Manager',
    'invoices' => array(
        'invoicePrefix' => 'Enter invoice prefix',
        'estimatePrefix' => 'Enter estimate prefix',
        'creditNotePrefix' => 'Enter credit note prefix',
        'gstNumber' => 'Enter Tax Number',
        'invoiceTerms' => 'Enter invoice terms',
        'description' => 'Enter Description (optional)',
        'note' => 'e.g. Thank you for your business',
        'terms' => 'Include your return and cancellation policy',
    ),

    'currency' => array(
        'currencyName' => 'e.g. Dollar',
        'currencySymbol' => 'e.g. $',
        'currencyCode' => 'e.g. USD',
        'thousandSeparator' => 'e.g. ,',
        'decimalSeparator' => 'e.g. .',
    ),
    'ticket' => array(
        'replyTicket' => 'Enter template heading',
        'templateText' => 'Enter template text here',
    ),
    'columnName' => 'e.g. Pending',
    'message' => 'Write your message here',
    'payments' => array(
        'remark' => 'Enter summary of the payment.',
        'transactionId' => 'Enter transaction ID of the payment',
        'paymentGateway' => 'e.g. PayPal, Stripe, Bank Transfer, Cash etc.'
    ),
    'expense' => array(
        'item' => 'e.g. Wireless Keyboard',
        'vendor' => 'e.g. Acme Corporation'
    ),
    'status' => 'e.g. In Progress',
    'timelog' => array(
        'memo' => 'e.g. Working on new logo'
    ),
    'noticeTitle' => 'e.g. New year celebrations at office.',
    'search' => 'Enter keyword to search',
    'attendance' => array(
        'workFrom' => 'e.g. Office, Home, etc.'
    ),
    'dateRange' => 'Start Date To End Date',
    'emailDomain' => 'e.g. gmail.com',
    'slackWebhook' => 'e.g. https://hooks.slack.com/services/XXXXXXXXXXXXXXXXXXXX',
    'gdpr' => array(
        'additionDescription' => 'Enter Additional Description',
    ),
    'productName' => 'e.g. Web Hosting, Laptop, Notebook, Mobile App etc.',
    'leave' => array(
        'reason' => 'e.g. Feeling not well',
    ),
    'company' => 'e.g. Acme Corporation',
    'storageSetting' => array(
        'awsKey' => 'e.g. AKIAXXXXX67FNYNM2P',
        'awsBucket' => 'e.g. test-bucket',
    ),
    'hsnSac' => 'e.g. 995431',
    'hourEstimate' => 'e.g. 500',
    'paymentGateway' => array(
        'sandboxPaypalClientId' => 'e.g. AW-Ydt5KHz2FwhAikHsObpRrpB55qE8MyvUkHbQsFb_6_2Unv3WNBSmBxEqA8N74JzOaFTPBUI-MG4sB',
        'livePaypalClientId' => 'e.g. AW-Ydt5KHz2FwhAikHsObpRrpB55qE8MyvUkHbQsFb_6_2Unv3WNBSmBxEqA8N74JzOaFTPBUI-MG4sB',
        'testStripePublishableKey' => 'e.g. sk_test_XXXXXXXXXXxBXnjBe1d6G5reXbGAc8a1qumQN0doumYbhb2tChV6qTCuFfvQyxEDInYho7jhQoR4MqNBWcafRYPCb00r2jkEBKe',
        'liveStripePublishableKey' => 'e.g. sk_live_51GbndSLM4xBXnjBe1d6G5reXbGAc8a1qumQN0doumYbhb2tChV6qTCuFfvQyxEDInYho7jhQoR4MqNBWcafRYPCbXXXXXXXXX',
        'testRazorpayKey' => 'e.g. rzp_test_znKZOLXXT3XXEX',
        'liveRazorpayKey' => 'e.g. rzp_live_znKZOLn4TXXXXX',
        'paystackKey' => 'e.g. pk_live_XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
        'flutterwaveKey' => 'e.g. FLWPUBK-xxxxxxxxxxxxxxxxxxxxx-X',
    ),
    'renterPassword' => 'Please enter your password',
    'city' => 'e.g. New York, Jaipur, Dubai',
    'location' => 'Enter a location',
    'website' => 'e.g. https://www.example.com',
    'relationship' => 'e.g. father',
    'shiftName' => 'e.g. Night Shift',
    'shiftShortCode' => 'e.g. NS',
);

==> worksuite-v5.5.12.zip: worksuite-new-5.5.12/script/resources/lang/en/placeholders.php <==
<?php

return array(
    'knowledgeBase' => 'Update your profile picture',
    'writeshortcode' => 'Project unique short code',
    'taskshortcode' => 'Task unique short code',
    'name' => 'e.g. John Doe',
    'email' => 'e.g. johndoe@example.com',
    'mobile' => 'e.g. 1234567890',
    'mobileWithPlus' => 'e.g. +19876543',
    'password' => 'Must have at least 8 characters',
    'designation' => 'e.g. Team Lead',
    'department' => 'e.g. Human Resource',
    'date' => 'Select Date',
    'address' => 'e.g. 132, My Street, Kingston, New York 12401',
    'skills' => 'e.g. communication, ReactJS',
    'project' => 'Write a project name',
    'price' => 'e.g. 10000',
    'hours' => 'e.g. 10:00 AM',
    'category' => 'Enter a category name',
    'task' => 'Enter a task title',
    'label' => 'Enter a label title',
    'leaveType' => 'E.g. Sick, Casual',
    'colorPicker' => 'Select a color',
    'ticketType' => 'e.g. Support',
    'milestone' => 'Enter milestone title',
    'milestoneSummary' => 'Enter milestone summary',
    'sampleText' => 'e.g. This is sample text',
    'webhook' => 'e.g. samplewebhook123',
    'key' => 'e.g. 0f99088a2f31e70daxxxx',
    'secret' => 'e.g. cbabcd0948aed7dd9xxxx',
    'id' => 'e.g. 1275901',
    'cluster' => 'e.g. ap2',
    'note' => 'Enter note title',
    'consent' => 'Enter consent name',
    'consentDescription' => 'Briefly describe the purpose of consent',
    'title' => 'e.g. Manager',
    'noneSelectedText' => 'Nothing selected',
    'noneResultsText' => 'No results matched {0}',
    'selectAllText' => 'Select All',
    'deselectAllText' => 'Deselect All',
    'linkTitle' => 'Link Title',
    'url' => 'URL',
    'categoryName' => "e.g. Finance",
    'invoices' => array(
        'invoicePrefix' => 'Enter invoice prefix',
        'estimatePrefix' => 'Enter estimate prefix',
        'creditNotePrefix' => 'Enter credit note prefix',
        'contractNumber' => 'Enter contract number',
        'gstNumber' => 'Enter Tax Number',
        'invoiceTerms' => 'Enter invoice terms',
        'description' => 'Enter Description (optional)',
        'note' => 'e.g. Thank you for your business',
        'terms' => 'Include your return and cancellation policy',
        'invoiceNumberSeparator' => 'Invoice Number Separator',
        'estimateNumberSeparator' => 'Estimate Number Separator',
        'credit_noteNumberSeparator' => 'Credit Note Number Separator',
        'contractNumberSeparator' => 'Contract Number Separator',
        'contractPrefix' => 'Contract Prefix',
        'otherInfo' => 'Enter Other Information',
    ),

    'currency' => array(
        'currencyName' => 'e.g. Dollar',
        'currencySymbol' => 'e.g. $',
        'currencyCode' => 'e.g. USD',
        'thousandSeparator' => 'e.g. ,',
        'decimalSeparator' => 'e.g. .',
    ),
    'ticket' => array(
        'replyTicket' => 'Enter template heading',
        'templateText' => 'Enter template text here',
    ),
    'columnName' => 'e.g. Pending',
    'message' => 'Write your message here',
    'payments' => array(
        'remark' => 'Enter a summary of the payment.',
        'transactionId' => 'Enter transaction ID of the payment',
        'paymentGateway' => 'e.g. PayPal, Stripe, Bank Transfer, Cash etc.'
    ),
    'expense' => array(
        'item' => 'e.g. Wireless Keyboard',
        'vendor' => 'e.g. Acme Corporation'
    ),
    'status' => 'e.g. In Progress',
    'timelog' => array(
        'memo' => 'e.g. Working on new logo'
    ),
    'noticeTitle' => 'e.g. New year celebrations at office.',
    'search' => 'Enter keyword to search',
    'attendance' => array(
        'workFrom' => 'e.g. Office, Home, etc.'
    ),
    'dateRange' => 'Start Date To End Date',
    'emailDomain' => 'e.g. gmail.com',
    'slackWebhook' => 'e.g. https://hooks.slack.com/services/XXXXXXXXXXXXXXXXXXXX',
    'gdpr' => array(
        'additionDescription' => 'Enter Additional Description',
    ),
    'productName' => 'e.g. Web Hosting, Laptop, Notebook, Mobile App etc.',
    'leave' => array(
        'reason' => 'e.g. Feeling not well',
    ),
    'company' => 'e.g. Acme Corporation',
    'storageSetting' => array(
        'awsKey' => 'e.g. AKIAXXXXX67FNYNM2P',
        'awsBucket' => 'e.g. test-bucket',
    ),
    'hsnSac' => 'e.g. 995431',
    'sku' => "Write the product's sku here",
    'hourEstimate' => 'e.g. 500',
    'paymentGateway' => array(
        'sandboxPaypalClientId' => 'e.g. AW-Ydt5KHz2FwhAikHsObpRrpB55qE8MyvUkHbQsFb_6_2Unv3WNBSmBxEqA8N74JzOaFTPBUI-MG4sB',
        'livePaypalClientId' => 'e.g. AW-Ydt5KHz2FwhAikHsObpRrpB55qE8MyvUkHbQsFb_6_2Unv3WNBSmBxEqA8N74JzOaFTPBUI-MG4sB',
        'testStripePublishableKey' => 'e.g. sk_test_XXXXXXXXXXxBXnjBe1d6G5reXbGAc8a1qumQN0doumYbhb2tChV6qTCuFfvQyxEDInYho7jhQoR4MqNBWcafRYPCb00r2jkEBKe',
        'liveStripePublishableKey' => 'e.g. sk_live_51GbndSLM4xBXnjBe1d6G5reXbGAc8a1qumQN0doumYbhb2tChV6qTCuFfvQyxEDInYho7jhQoR4MqNBWcafRYPCbXXXXXXXXX',
        'testRazorpayKey' => 'e.g. rzp_test_znKZOLXXT3XXEX',
        'liveRazorpayKey' => 'e.g. rzp_live_znKZOLn4TXXXXX',
        'paystackKey' => 'e.g. pk_live_XXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXXX',
        'flutterwaveKey' => 'e.g. FLWPUBK-xxxxxxxxxxxxxxxxxxxxx-X',
    ),
    'bankaccount' => array(
        'accountName' => 'e.g. John Doe',
        'bankName' => 'e.g. Federal Bank',
        'accountNumber' => 'e.g. 123456789',
        'balance' => 'e.g. 25$',
    ),
    'renterPassword' => 'Please enter your password',
    'city' => 'e.g. New York, Jaipur, Dubai',
    'location' => 'Enter a location',
    'website' => 'e.g. https://www.example.com',
    'relationship' => 'e.g. father',
    'shiftName' => 'e.g. Night Shift',
    'shiftShortCode' => 'e.g. NS',
    'appreciation' => array(
        'title' => 'e.g. Employee of the month'
    ),
    'select2Min' => 'Please enter 2 or more characters',
    'searchForProjects' => 'Search for projects',
    'min' => 'Min',
    'max' => 'Max',
    'consent_description' => 'consent description',
    'recaptchaV2' => 'e.g. 6LeL_s8ZAAAAAMVC2clQdxxxXXXxxxxxXXX',
    'recaptchaSecret' => 'e.g. XXXXXXxxxxxXXXXXXxxxxx',
    'recaptchaV3' => 'e.g. 6LeL_s8ZAAAAAMVC2clQdxxxXXXxxxxxXXX',
    'fileSetting' => 'e.g. application/x-zip-compressed',
    'searchForCompany' => 'Search For A Compnay',
    'tickets' => array(
        'ticketChannel' => 'e.g. Facebook, Phone, etc.',
        'ticketGroup' => 'e.g. Sales, Support, etc.',
    ),
    'offlinePayment' => array(
        'method' => 'e.g. Cash, Cheque, etc.',
        'description' => 'e.g. via USD dollar',
    ),
    'state' => 'e.g. California, Rajasthan, Dubai',
    'postalCode' => 'e.g. 90250',
    'gstNumber' => 'e.g. 18AABCU960XXXXX',
    'latitude' => 'e.g. 38.895',
    'longitude' => 'e.g. -77.0364',
    'client' => array(
        'skype' => 'e.g. skypeUsername',
        'linkedin' => 'e.g. https://www.linkedin.com/XXXXXXXXXX/',
        'twitter' => 'e.g. @johndoe',
        'facebook' => 'e.g. https://www.facebook.com/XXXXXXXXXX/',
    ),
    'googleMapKey' => 'e.g. AIzaSyDSl2bG7XXXXXXXXXXXXXXXXXX',
    'categoryName' => 'e.g. Potential Client',
    'role' => array(
        'roleName' => 'e.g. HR',
    ),
    'purchaseCode' => 'e.g. 147778a2-dfa2-424e-a29f-xxxxxxxxx',
    'language' => array(
        'languageName' => 'e.g. English',
        'languageCode' => 'e.g. en',
    ),
    'gst/vat' => 'e.g. GST/VAT',
);
